@@ -83,24 +83,26 @@ def cerf_parallel(model, data, write_output=True, n_jobs=-1, method='sequential'
 
     # run all regions in parallel
     results = Parallel(n_jobs=n_jobs, backend=method)(delayed(process_region)(target_region_name=i,
-                                                                             settings_dict=model.settings_dict,
-                                                                             technology_dict=model.technology_dict,
-                                                                             technology_order=model.technology_order,
-                                                                             expansion_dict=model.expansion_dict,
-                                                                             regions_dict=model.regions_dict,
-                                                                             suitability_arr=data.suitability_arr,
-                                                                             lmp_arr=data.lmp_arr,
-                                                                             nov_arr=data.nov_arr,
-                                                                             ic_arr=data.ic_arr,
-                                                                             nlc_arr=data.nlc_arr,
-                                                                             zones_arr=data.zones_arr,
-                                                                             xcoords=data.xcoords,
-                                                                             ycoords=data.ycoords,
-                                                                             indices_2d=data.indices_2d,
-                                                                             randomize=model.settings_dict.get('randomize', True),
-                                                                             seed_value=model.settings_dict.get('seed_value', 0),
-                                                                             verbose=model.settings_dict.get('verbose', False),
-                                                                             write_output=False) for i in model.regions_dict.keys())
+                                                                              settings_dict=model.settings_dict,
+                                                                              technology_dict=model.technology_dict,
+                                                                              technology_order=model.technology_order,
+                                                                              expansion_dict=model.expansion_dict,
+                                                                              regions_dict=model.regions_dict,
+                                                                              suitability_arr=data.suitability_arr,
+                                                                              lmp_arr=data.lmp_arr,
+                                                                              generation_arr=data.generation_arr,
+                                                                              operating_cost_arr=data.operating_cost_arr,
+                                                                              nov_arr=data.nov_arr,
+                                                                              ic_arr=data.ic_arr,
+                                                                              nlc_arr=data.nlc_arr,
+                                                                              zones_arr=data.zones_arr,
+                                                                              xcoords=data.xcoords,
+                                                                              ycoords=data.ycoords,
+                                                                              indices_2d=data.indices_2d,
+                                                                              randomize=model.settings_dict.get('randomize', True),
+                                                                              seed_value=model.settings_dict.get('seed_value', 0),
+                                                                              verbose=model.settings_dict.get('verbose', False),
+                                                                              write_output=False) for i in model.regions_dict.keys())
 
     logging.info(f"All regions processed in {round((time.time() - t0), 7)} seconds.")
     logging.info("Aggregating outputs...")
