@@ -1,5 +1,6 @@
-
+import os
 import logging
+import tempfile
 
 import numpy as np
 import pandas as pd
@@ -260,7 +261,10 @@ def raster_to_coord_arrays(template_raster):
     return x, y
 
 
-def ingest_sited_data(run_year, x_array, siting_data):
+def ingest_sited_data(run_year,
+                      x_array,
+                      siting_data,
+                      template_raster_file: str):
     """Import sited data containing the locations and additional data to establish an initial suitability condition
     representing power plants and their siting buffer.
 
@@ -277,13 +281,14 @@ def ingest_sited_data(run_year, x_array, siting_data):
     :param x_array:                         2D array of X coordinates for the entire grid space
     :type x_array:                          ndarray
 
-    :param y_array:                         2D array of Y coordinates for the entire grid space
-    :type y_array:                          ndarray
-
     :param siting_data:                     Full path with file name and extension for the input siting file or a
                                             Pandas DataFrame
     :type siting_data:                      str, DataFrame
 
+    :param template_raster_file:            Full path with file name and extension to the input template raster file
+                                            containing a grid index value per grid cell.
+    :type template_raster_file:             str
+
     :return:                                [0] 2D array of 0 (suitable) and 1 (unsuitable) values where 1 are the sites
                                             and their buffers of active power plants
 
@@ -307,6 +312,42 @@ def ingest_sited_data(run_year, x_array, siting_data):
     # initialize an array to hold the 0, 1 sited and buffer data
     sited_arr = np.zeros_like(x_array).flatten()
 
+    # generate the corresponding grid index for the input coordinate pairs
+    with rasterio.open(template_raster_file) as src:
+        metadata = src.meta.copy()
+
+        # get array
+        arr = src.read(1)
+        n_cells = arr.shape[0] * arr.shape[1]
+        max_allowable_cells = np.iinfo(rasterio.uint32).max
+
+        if n_cells > max_allowable_cells:
+            raise ValueError(f"Too many grid cells in array for a uint32 format.  Max allowable: {max_allowable_cells}")
+
+        # create continuous index values from flat array and then reshape back to 2D
+        flat_arr = np.array(range(arr.shape[0] * arr.shape[1]))
+        index_arr = flat_arr.reshape((arr.shape[0], arr.shape[1])).astype(np.uint32)
+
+        # update data type
+        metadata.update(dtype=np.uint32)
+
+    with tempfile.TemporaryDirectory() as tempdir:
+
+        # construct temporary raster file name
+        out_temp_rast = os.path.join(tempdir, "cerf_temp_raster.tif")
+
+        # write array as spatial in a temp file
+        with rasterio.open(out_temp_rast, "w", **metadata) as dest:
+            dest.write(index_arr, 1)
+
+        # read temp file to use for grid search
+        with rasterio.open(out_temp_rast) as idx:
+            index_generator = idx.sample(df_active[["xcoord", "ycoord"]].values)
+            located_index_list = [i[0] for i in index_generator]
+
+    # give the input data frame the new index from the coordinate lookup
+    df_active["index"] = located_index_list
+
     for ix in df_active['index'].tolist():
 
         # get the buffer size for the site
